% RMS E-FIELD COMPARISON WITH 4NEC2  (valdipoles1)
% 
% Example showing the using the plot_field_slice1.m function
%
% In this case two 1GHz dipoles are placed 2*lambda apart on the x-y plane.
% The waves propagating from each dipole interfere with each other, causing 
% regions of wave reinforcement and wave cancellation.
%
% The same model has been run in 4NEC2 for comparision. From the graphs it
% can be seen that ArrayCalc's near-field calculation is quite accurate at
% a distance of 1*lambda (0.3m) from the dipoles.
%

close all
clc
help valdipoles1

init;                              % Initialise global variables
arraypwr_config=100;               % Set array power to 100W
arrayeff_config=100;               % Set array efficiency to 100%
freq_config=1e9;                   % Set frequency (Hz)
lambda=3e8/(freq_config);          % Calculate wavelength (m)
dipole_config=lambda/2;            % Set dipole length to lambda/2 (m)

% *********  Array definition **********

single_element(0,-1*lambda,0,'dipole',0,0);
single_element(0,+1*lambda,0,'dipole',0,0);
yrot_array(90,1,2);
zrot_array(90,1,2);

% *****  Plot geometry and patterns ****

plot_geom3d(1,0);      % Plot 3D geometry with axis (uses standard figure1)
view([140,40]);        % Select view
plot_geom3d1(1,1,20);  % Plot 3D geometry with axis and element excitations in figure 20
view([140,40]);         % Select view
axis equal;

list_array(0);         % List the array x,y,z locations and excitations only
norm_array;
list_array(0);

calc_directivity(10,10);


% ******** Field slice plot *********

dBrange_config=40;  % Set dynamic range for field slice plots (dB)

xrng=1;      % Dimension of slice in local x-direction (m)
yrng=xrng;   % Dimension of slice in local y-direction (m)
xsteps=100;  % Number of steps in x
ysteps=100;  % Number of steps in y
xrot=0;        % Rotation about x-axis (deg)
yrot=0;        % Rotation about y-axis (deg)
zrot=0;        % Rotation about z-axis (deg)
xoff=0;                   % Offset in x (m)
yoff=0;                   % Offset in y (m)
zoff=0;                   % Offset in z (m)
polarisation='vp';     % Plot parameter (string)
normalise='no';         % Normalisation option (string)
units='vm';             % Display units (string)
fignum1=1;              % Figure number for plot in global coordinates (numeric)
fignum2=21;             % Figure number for plot in local/global coords as appropriate (numeric)

% Generate field-slice plots in global and local coordinates, fignum1 / fignum2   
[XGC,YGC,ZGC,XLC,YLC,ZLC,PlotData]=plot_field_slice1(xrng,xsteps,yrng,ysteps,xrot,yrot,zrot,...
   xoff,yoff,zoff,polarisation,normalise,units,fignum1,fignum2);    

% Fine tune the plots generated by plot_field_slice1

figure(fignum2);  % Select the figure for the slice-plot in local coordinates
warning off;      % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;
caxis([0,2000]);
colorbar;

figure(fignum1);  % Select the figure for the slice plot in global coordinates.
                  % In this case figure1 which already has the 3D array geometry on it.
axis equal;
warning off;     % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;
caxis([0,2000]);
colorbar;

% Modify the title for 3D geometry plot in figure(fignum1)
title('3D Geometry TOT Field Slice (RMS V/m) at Z=0m');

% Plot flux density profile along X-axis
[acX,acE1]=plot_line_slice(-xrng/2,0,zoff,+xrng/2,0,zoff,101,polarisation,normalise,units,fignum1,25);
% Plot flux density profile along Y-axis
[acY,acE2]=plot_line_slice(0,-yrng/2,zoff,0,+yrng/2,zoff,101,polarisation,normalise,units,fignum1,26);

% Data from 4NEC2 Dipoles.nec nearfield analysis
% **********************************************

% Xcut for Y=0

NECdata1=[-0.50        289.10
         -0.49        300.13
         -0.48        312.06
         -0.47        324.99
         -0.46        339.04
         -0.45        354.33
         -0.44        371.01
         -0.43        389.24
         -0.42        409.18
         -0.41        430.99
         -0.40        454.83
         -0.39        480.81
         -0.38        509.02
         -0.37        539.47
         -0.36        572.13
         -0.35        607.22
         -0.34        646.11
         -0.33        694.74
         -0.32        778.24
         -0.31       1038.10
         -0.30       5704.09
         -0.29       1009.75
         -0.28        717.43
         -0.27        602.53
         -0.26        526.20
         -0.25        466.45
         -0.24        421.00
         -0.23        391.57
         -0.22        378.80
         -0.21        380.03
         -0.20        390.01
         -0.19        402.70
         -0.18        412.89
         -0.17        416.74
         -0.16        411.78
         -0.15        396.66
         -0.14        371.00
         -0.13        335.20
         -0.12        290.38
         -0.11        238.41
         -0.10        182.15
         -0.09        126.83
         -0.08         85.78
         -0.07         87.14
         -0.06        126.94
         -0.05        176.26
         -0.04        222.99
         -0.03        262.46
         -0.02        292.16
         -0.01        310.55
             0        316.74
          0.01        310.55
          0.02        292.16
          0.03        262.46
          0.04        222.99
          0.05        176.26
          0.06        126.94
          0.07         87.14
          0.08         85.78
          0.09        126.83
          0.10        182.15
          0.11        238.41
          0.12        290.38
          0.13        335.20
          0.14        371.00
          0.15        396.66
          0.16        411.78
          0.17        416.74
          0.18        412.89
          0.19        402.70
          0.20        390.01
          0.21        380.03
          0.22        378.80
          0.23        391.57
          0.24        421.00
          0.25        466.45
          0.26        526.20
          0.27        602.53
          0.28        717.43
          0.29       1009.75
          0.30       5704.09
          0.31       1038.10
          0.32        778.24
          0.33        694.74
          0.34        646.11
          0.35        607.22
          0.36        572.13
          0.37        539.47
          0.38        509.02
          0.39        480.81
          0.40        454.83
          0.41        430.99
          0.42        409.18
          0.43        389.24
          0.44        371.01
          0.45        354.33
          0.46        339.04
          0.47        324.99
          0.48        312.06
          0.49        300.13
          0.50        289.10];
 
 necX=NECdata1(:,1);
 necE1=NECdata1(:,2);
 
 % Ycut for X=0
 
NECdata2=[-0.5000  166.8277
   -0.4900  169.2672
   -0.4800  171.7633
   -0.4700  174.3160
   -0.4600  176.9323
   -0.4500  179.6051
   -0.4400  182.3487
   -0.4300  185.1488
   -0.4200  188.0126
   -0.4100  190.9471
   -0.4000  193.9453
   -0.3900  197.0070
   -0.3800  200.1395
   -0.3700  203.3356
   -0.3600  206.5954
   -0.3500  209.9259
   -0.3400  213.3200
   -0.3300  216.7848
   -0.3200  220.3062
   -0.3100  223.8912
   -0.3000  227.5328
   -0.2900  231.2310
   -0.2800  234.9787
   -0.2700  238.7688
   -0.2600  242.6083
   -0.2500  246.4833
   -0.2400  250.3865
   -0.2300  254.3039
   -0.2200  258.2354
   -0.2100  262.1740
   -0.2000  266.0984
   -0.1900  269.9946
   -0.1800  273.8625
   -0.1700  277.6738
   -0.1600  281.4144
   -0.1500  285.0772
   -0.1400  288.6339
   -0.1300  292.0634
   -0.1200  295.3514
   -0.1100  298.4839
   -0.1000  301.4255
   -0.0900  304.1620
   -0.0800  306.6793
   -0.0700  308.9561
   -0.0600  310.9644
   -0.0500  312.6967
   -0.0400  314.1393
   -0.0300  315.2706
   -0.0200  316.0838
   -0.0100  316.5788
         0  316.7414
    0.0100  316.5788
    0.0200  316.0838
    0.0300  315.2706
    0.0400  314.1393
    0.0500  312.6967
    0.0600  310.9644
    0.0700  308.9561
    0.0800  306.6793
    0.0900  304.1620
    0.1000  301.4255
    0.1100  298.4839
    0.1200  295.3514
    0.1300  292.0634
    0.1400  288.6339
    0.1500  285.0772
    0.1600  281.4144
    0.1700  277.6738
    0.1800  273.8625
    0.1900  269.9946
    0.2000  266.0984
    0.2100  262.1740
    0.2200  258.2354
    0.2300  254.3039
    0.2400  250.3865
    0.2500  246.4833
    0.2600  242.6083
    0.2700  238.7688
    0.2800  234.9787
    0.2900  231.2310
    0.3000  227.5328
    0.3100  223.8912
    0.3200  220.3062
    0.3300  216.7848
    0.3400  213.3200
    0.3500  209.9259
    0.3600  206.5954
    0.3700  203.3356
    0.3800  200.1395
    0.3900  197.0070
    0.4000  193.9453
    0.4100  190.9471
    0.4200  188.0126
    0.4300  185.1488
    0.4400  182.3487
    0.4500  179.6051
    0.4600  176.9323
    0.4700  174.3160
    0.4800  171.7633
    0.4900  169.2672
    0.5000  166.8277];
 
 necY=NECdata2(:,1);
 necE2=NECdata2(:,2);
 
figure(27);
hold on;
p1=plot(acX,acE1,'r','linewidth',2);
p2=plot(necX,necE1,'r+','linewidth',1);
plot(necX,necE1,'r:','linewidth',1);
p3=plot(acY,acE2,'b','linewidth',2);
p4=plot(necY,necE2,'b+','linewidth',1);

T1=sprintf('ACalc Xcut for Y=0');
T2=sprintf('4NEC2 Xcut for Y=0');
T3=sprintf('ACalc Ycut for X=0');
T4=sprintf('4NEC2 Ycut for X=0');

legend([p1,p2,p3,p4],T1,T2,T3,T4);
xlabel('Distance (m)')
ylabel('RMS E-field (V/m)');
title('TOT E-field along central axes of field-slice at Z=0m');
axis([-xrng/2 +xrng/2 0 2000]);
hold on;
grid on
zoom on
set(gcf,'name','4NEC2 Comparison');