% RMS E-FIELD COMPARISON WITH 4NEC2  (valdipoles3)
% 
% Example showing the using the plot_field_slice1.m function
%
% In this case two 1GHz dipoles are placed 2*lambda apart on the x-y plane.
% The waves propagating from each dipole interfere with each other, causing 
% regions of wave reinforcement and wave cancellation.
%
% The same model has been run in 4NEC2 for comparision. From the graphs it
% can be seen that ArrayCalc's near-field calculation is very accurate at
% a distance of 2*lambda (0.6m) from the dipoles.
%

close all
clc
help valdipoles3

init;                              % Initialise global variables
arraypwr_config=100;               % Set array power to 100W
arrayeff_config=100;               % Set array efficiency to 100%
freq_config=1e9;                   % Set frequency (Hz)
lambda=3e8/(freq_config);          % Calculate wavelength (m)
dipole_config=lambda/2;            % Set dipole length to lambda/2 (m)

% *********  Array definition **********

single_element(0,-1*lambda,0,'dipole',0,0);
single_element(0,+1*lambda,0,'dipole',0,0);
yrot_array(90,1,2);
zrot_array(90,1,2);

% *****  Plot geometry and patterns ****

plot_geom3d(1,0);      % Plot 3D geometry with axis (uses standard figure1)
view([140,40]);        % Select view
plot_geom3d1(1,1,20);  % Plot 3D geometry with axis and element excitations in figure 20
view([140,40]);         % Select view
axis equal;

list_array(0);         % List the array x,y,z locations and excitations only
norm_array;
list_array(0);

calc_directivity(10,10);


% ******** Field slice plot *********

dBrange_config=40;  % Set dynamic range for field slice plots (dB)

xrng=2;      % Dimension of slice in local x-direction (m)
yrng=xrng;   % Dimension of slice in local y-direction (m)
xsteps=100;  % Number of steps in x
ysteps=100;  % Number of steps in y
xrot=90;       % Rotation about x-axis (deg)
yrot=0;        % Rotation about y-axis (deg)
zrot=0;        % Rotation about z-axis (deg)
xoff=0;                   % Offset in x (m)
yoff=lambda*2;            % Offset in y (m)
zoff=0;                   % Offset in z (m)
polarisation='tot';     % Plot parameter (string)
normalise='no';         % Normalisation option (string)
units='vm';             % Display units (string)
fignum1=1;              % Figure number for plot in global coordinates (numeric)
fignum2=21;             % Figure number for plot in local/global coords as appropriate (numeric)

% Generate field-slice plots in global and local coordinates, fignum1 / fignum2   
[XGC,YGC,ZGC,XLC,YLC,ZLC,PlotData]=plot_field_slice1(xrng,xsteps,yrng,ysteps,xrot,yrot,zrot,...
   xoff,yoff,zoff,polarisation,normalise,units,fignum1,fignum2);    

% Fine tune the plots generated by plot_field_slice1

figure(fignum2);  % Select the figure for the slice-plot in local coordinates
warning off;      % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;
caxis([0,150]);
colorbar;

figure(fignum1);  % Select the figure for the slice plot in global coordinates.
                  % In this case figure1 which already has the 3D array geometry on it.
axis equal;
warning off;     % Lots of grumbling from Matlab about color data and shading, but seems to work OK
shading flat;
caxis([0,150]);
colorbar;

% Modify the title for 3D geometry plot in figure(fignum1)
title('3D Geometry TOT Field Slice (RMS V/m) at Y=0.6m');

% Plot flux density profile along X-axis
[acX,acE1]=plot_line_slice(-xrng/2,yoff,0,+xrng/2,yoff,0,101,polarisation,normalise,units,fignum1,25);
% Plot flux density profile along Z-axis
[acY,acE2]=plot_line_slice(0,yoff,-yrng/2,0,yoff,+yrng/2,101,polarisation,normalise,units,fignum1,26);

% Data from 4NEC2 Dipoles.nec nearfield analysis
% **********************************************

% Xcut for Z=0

NECdata1=[        -1.00         53.06
         -0.98         51.76
         -0.96         50.28
         -0.94         48.62
         -0.92         46.76
         -0.90         44.70
         -0.88         42.44
         -0.86         39.99
         -0.84         37.38
         -0.82         34.65
         -0.80         31.91
         -0.78         29.29
         -0.76         27.07
         -0.74         25.60
         -0.72         25.34
         -0.70         26.66
         -0.68         29.68
         -0.66         34.26
         -0.64         40.14
         -0.62         47.05
         -0.60         54.76
         -0.58         63.08
         -0.56         71.83
         -0.54         80.86
         -0.52         89.95
         -0.50         98.90
         -0.48        107.49
         -0.46        115.44
         -0.44        122.46
         -0.42        128.25
         -0.40        132.48
         -0.38        134.80
         -0.36        134.91
         -0.34        132.50
         -0.32        127.32
         -0.30        119.19
         -0.28        108.02
         -0.26         93.85
         -0.24         76.86
         -0.22         57.49
         -0.20         36.67
         -0.18         18.16
         -0.16         21.76
         -0.14         42.99
         -0.12         66.00
         -0.10         87.89
         -0.08        107.42
         -0.06        123.63
         -0.04        135.78
         -0.02        143.30
             0        145.85
          0.02        143.30
          0.04        135.78
          0.06        123.63
          0.08        107.42
          0.10         87.89
          0.12         66.00
          0.14         42.99
          0.16         21.76
          0.18         18.16
          0.20         36.67
          0.22         57.49
          0.24         76.86
          0.26         93.85
          0.28        108.02
          0.30        119.19
          0.32        127.32
          0.34        132.50
          0.36        134.91
          0.38        134.80
          0.40        132.48
          0.42        128.25
          0.44        122.46
          0.46        115.44
          0.48        107.49
          0.50         98.90
          0.52         89.95
          0.54         80.86
          0.56         71.83
          0.58         63.08
          0.60         54.76
          0.62         47.05
          0.64         40.14
          0.66         34.26
          0.68         29.68
          0.70         26.66
          0.72         25.34
          0.74         25.60
          0.76         27.07
          0.78         29.29
          0.80         31.91
          0.82         34.65
          0.84         37.38
          0.86         39.99
          0.88         42.44
          0.90         44.70
          0.92         46.76
          0.94         48.62
          0.96         50.28
          0.98         51.76
          1.00         53.06];
 
 necX=NECdata1(:,1);
 necE1=NECdata1(:,2);
 
 % Zcut for X=0
 
NECdata2=[         -1.00         35.57
         -0.98         36.69
         -0.96         37.86
         -0.94         39.07
         -0.92         40.34
         -0.90         41.66
         -0.88         43.05
         -0.86         44.48
         -0.84         45.98
         -0.82         47.55
         -0.80         49.18
         -0.78         50.88
         -0.76         52.66
         -0.74         54.51
         -0.72         56.43
         -0.70         58.44
         -0.68         60.52
         -0.66         62.70
         -0.64         64.95
         -0.62         67.30
         -0.60         69.73
         -0.58         72.26
         -0.56         74.87
         -0.54         77.57
         -0.52         80.36
         -0.50         83.23
         -0.48         86.19
         -0.46         89.22
         -0.44         92.32
         -0.42         95.49
         -0.40         98.70
         -0.38        101.96
         -0.36        105.25
         -0.34        108.56
         -0.32        111.87
         -0.30        115.15
         -0.28        118.39
         -0.26        121.57
         -0.24        124.67
         -0.22        127.64
         -0.20        130.49
         -0.18        133.17
         -0.16        135.65
         -0.14        137.92
         -0.12        139.94
         -0.10        141.70
         -0.08        143.17
         -0.06        144.33
         -0.04        145.17
         -0.02        145.68
             0        145.85
          0.02        145.68
          0.04        145.17
          0.06        144.33
          0.08        143.17
          0.10        141.70
          0.12        139.94
          0.14        137.92
          0.16        135.65
          0.18        133.17
          0.20        130.49
          0.22        127.64
          0.24        124.67
          0.26        121.57
          0.28        118.39
          0.30        115.15
          0.32        111.87
          0.34        108.56
          0.36        105.25
          0.38        101.96
          0.40         98.70
          0.42         95.49
          0.44         92.32
          0.46         89.22
          0.48         86.19
          0.50         83.23
          0.52         80.36
          0.54         77.57
          0.56         74.87
          0.58         72.26
          0.60         69.73
          0.62         67.30
          0.64         64.95
          0.66         62.70
          0.68         60.52
          0.70         58.44
          0.72         56.43
          0.74         54.51
          0.76         52.66
          0.78         50.88
          0.80         49.18
          0.82         47.55
          0.84         45.98
          0.86         44.48
          0.88         43.05
          0.90         41.66
          0.92         40.34
          0.94         39.07
          0.96         37.86
          0.98         36.69
          1.00         35.57];
 
 necY=NECdata2(:,1);
 necE2=NECdata2(:,2);
 
figure(27);
hold on;
p1=plot(acX,acE1,'r','linewidth',2);
p2=plot(necX,necE1,'r+','linewidth',1);
p3=plot(acY,acE2,'b','linewidth',2);
p4=plot(necY,necE2,'b+','linewidth',1);

T1=sprintf('ACalc Xcut for Z=0');
T2=sprintf('4NEC2 Xcut for Z=0');
T3=sprintf('ACalc Zcut for X=0');
T4=sprintf('4NEC2 Zcut for X=0');

legend([p1,p2,p3,p4],T1,T2,T3,T4,4);
xlabel('Distance (m)')
ylabel('RMS E-field (V/m)');
title('TOT E-field along central axes of field-slice at Y=0.6m');
axis([-xrng/2 +xrng/2 0 150]);
hold on;
grid on
zoom on
set(gcf,'name','4NEC2 Comparison');